@@ -1,12 +1,38 @@
 /*
- * MUSCLE SmartCard Development ( http://www.linuxnet.com )
+ * MUSCLE SmartCard Development ( http://pcsclite.alioth.debian.org/pcsclite.html )
  *
  * Copyright (C) 1999-2004
- *  David Corcoran <corcoran@linuxnet.com>
+ *  David Corcoran <corcoran@musclecard.com>
  * Copyright (C) 2002-2011
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: winscard.c 6391 2012-07-26 18:44:54Z rousseau $
+Redistribution and use in source and binary forms, with or without
+modification, are permitted provided that the following conditions
+are met:
+
+1. Redistributions of source code must retain the above copyright
+   notice, this list of conditions and the following disclaimer.
+2. Redistributions in binary form must reproduce the above copyright
+   notice, this list of conditions and the following disclaimer in the
+   documentation and/or other materials provided with the distribution.
+3. The name of the author may not be used to endorse or promote products
+   derived from this software without specific prior written permission.
+
+Changes to this license can be made only by the copyright author with
+explicit written consent.
+
+THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
+IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
+OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
+IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
+INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
+NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
+THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ * $Id: winscard.c 6851 2014-02-14 15:43:32Z rousseau $
  */
 
 /**
@@ -568,7 +594,6 @@ LONG SCardReconnect(SCARDHANDLE hCard, DWORD dwShareMode,
 			rv = IFDPowerICC(rContext, IFD_POWER_UP,
 				rContext->readerState->cardAtr, &dwAtrLen);
 		}
-		rContext->readerState->cardAtrLength = dwAtrLen;
 
 		/* the protocol is unset after a power on */
 		rContext->readerState->cardProtocol = SCARD_PROTOCOL_UNDEFINED;
@@ -1091,6 +1116,7 @@ exit:
 LONG SCardEndTransaction(SCARDHANDLE hCard, DWORD dwDisposition)
 {
 	LONG rv;
+	LONG rv2;
 	READER_CONTEXT * rContext = NULL;
 
 	/*
@@ -1214,7 +1240,13 @@ LONG SCardEndTransaction(SCARDHANDLE hCard, DWORD dwDisposition)
 	/*
 	 * Unlock any blocks on this context
 	 */
-	(void)RFUnlockSharing(hCard, rContext);
+	/* we do not want to lose the previous rv value
+	 * So we use another variable */
+	rv2 = RFUnlockSharing(hCard, rContext);
+	if (rv2 != SCARD_S_SUCCESS)
+		/* if rv is already in error then do not change its value */
+		if (rv == SCARD_S_SUCCESS)
+			rv = rv2;
 
 	Log2(PCSC_LOG_DEBUG, "Status: 0x%08lX", rv);
 
@@ -1391,20 +1423,20 @@ LONG SCardGetAttrib(SCARDHANDLE hCard, DWORD dwAttrId,
 			/* Special case SCARD_ATTR_DEVICE_FRIENDLY_NAME as it is better
 			 * implemented in pcscd (it knows the friendly name)
 			 */
-			if (dwAttrId == SCARD_ATTR_DEVICE_FRIENDLY_NAME)
+			if ((SCARD_ATTR_DEVICE_FRIENDLY_NAME == dwAttrId)
+				|| (SCARD_ATTR_DEVICE_SYSTEM_NAME == dwAttrId))
 			{
 				unsigned int len = strlen(rContext->readerState->readerName)+1;
 
-				*pcbAttrLen = len;
 				if (len > *pcbAttrLen)
 					rv = SCARD_E_INSUFFICIENT_BUFFER;
 				else
 				{
 					(void)strlcpy((char *)pbAttr,
-						rContext->readerState->readerName, *pcbAttrLen);
+						rContext->readerState->readerName, len);
 					rv = SCARD_S_SUCCESS;
 				}
-
+				*pcbAttrLen = len;
 			}
 			else
 				rv = SCARD_E_UNSUPPORTED_FEATURE;
