@@ -1,14 +1,40 @@
 /*
- * MUSCLE SmartCard Development ( http://www.linuxnet.com )
+ * MUSCLE SmartCard Development ( http://pcsclite.alioth.debian.org/pcsclite.html )
  *
  * Copyright (C) 2001-2004
- *  David Corcoran <corcoran@linuxnet.com>
+ *  David Corcoran <corcoran@musclecard.com>
  * Copyright (C) 2003-2004
  *  Damien Sauveron <damien.sauveron@labri.fr>
  * Copyright (C) 2002-2010
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: winscard_msg_srv.c 4951 2010-05-18 09:35:09Z rousseau $
+Redistribution and use in source and binary forms, with or without
+modification, are permitted provided that the following conditions
+are met:
+
+1. Redistributions of source code must retain the above copyright
+   notice, this list of conditions and the following disclaimer.
+2. Redistributions in binary form must reproduce the above copyright
+   notice, this list of conditions and the following disclaimer in the
+   documentation and/or other materials provided with the distribution.
+3. The name of the author may not be used to endorse or promote products
+   derived from this software without specific prior written permission.
+
+Changes to this license can be made only by the copyright author with
+explicit written consent.
+
+THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
+IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
+OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
+IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
+INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
+NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
+THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ * $Id: winscard_msg_srv.c 6851 2014-02-14 15:43:32Z rousseau $
  */
 
 /**
@@ -39,6 +65,7 @@
 
 #include "misc.h"
 #include "pcscd.h"
+#include "sd-daemon.h"
 #include "winscard.h"
 #include "debuglog.h"
 #include "winscard_msg.h"
@@ -97,7 +124,11 @@ static int ProcessCommonChannelRequest(/*@out@*/ uint32_t *pdwClientID)
  */
 INTERNAL int32_t InitializeSocket(void)
 {
-	static struct sockaddr_un serv_adr;
+	union
+	{
+		struct sockaddr sa;
+		struct sockaddr_un un;
+	} sa;
 
 	/*
 	 * Create the common shared connection socket
@@ -109,17 +140,15 @@ INTERNAL int32_t InitializeSocket(void)
 		return -1;
 	}
 
-	serv_adr.sun_family = AF_UNIX;
-	strncpy(serv_adr.sun_path, PCSCLITE_CSOCK_NAME,
-		sizeof(serv_adr.sun_path));
+	memset(&sa, 0, sizeof sa);
+	sa.un.sun_family = AF_UNIX;
+	strncpy(sa.un.sun_path, PCSCLITE_CSOCK_NAME, sizeof sa.un.sun_path);
 	(void)remove(PCSCLITE_CSOCK_NAME);
 
-	if (bind(commonSocket, (struct sockaddr *) &serv_adr,
-			sizeof(serv_adr.sun_family) + strlen(serv_adr.sun_path) + 1) < 0)
+	if (bind(commonSocket, &sa.sa, sizeof sa) < 0)
 	{
 		Log2(PCSC_LOG_CRITICAL, "Unable to bind common socket: %s",
 			strerror(errno));
-		CleanupSharedSegment(commonSocket, PCSCLITE_CSOCK_NAME);
 		return -1;
 	}
 
@@ -127,18 +156,41 @@ INTERNAL int32_t InitializeSocket(void)
 	{
 		Log2(PCSC_LOG_CRITICAL, "Unable to listen common socket: %s",
 			strerror(errno));
-		CleanupSharedSegment(commonSocket, PCSCLITE_CSOCK_NAME);
 		return -1;
 	}
 
 	/*
 	 * Chmod the public entry channel
 	 */
-	(void)chmod(PCSCLITE_CSOCK_NAME, S_IRWXO | S_IRWXG | S_IRWXU);
+	(void)chmod(PCSCLITE_CSOCK_NAME, S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP | S_IROTH | S_IWOTH);
 
 	return 0;
 }
 
+/**
+ * @brief Acquires a socket passed in from systemd.
+ *
+ * This is called by the server to start listening on an existing socket for
+ * local IPC with the clients.
+ *
+ * @param fd The file descriptor to start listening on.
+ *
+ * @return Error code.
+ * @retval 0 Success
+ * @retval -1 Passed FD is not an UNIX socket.
+ */
+INTERNAL int32_t ListenExistingSocket(int fd)
+{
+	if (!sd_is_socket(fd, AF_UNIX, SOCK_STREAM, -1))
+	{
+		Log1(PCSC_LOG_CRITICAL, "Passed FD is not an UNIX socket");
+		return -1;
+	}
+
+	commonSocket = fd;
+	return 0;
+}
+
 /**
  * @brief Looks for messages sent by clients.
  *
